#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doclayout
version:              0.5.0.1
visibility:           public
id:                   doclayout-0.5.0.1-CujJ1EOYpiiKuHA7x2QcoQ
key:                  doclayout-0.5.0.1-CujJ1EOYpiiKuHA7x2QcoQ
license:              BSD-3-Clause
copyright:            2016-24 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doclayout
synopsis:             A prettyprinting library for laying out text documents.
description:
    doclayout is a prettyprinting library for laying out
    text documents, with several features not present
    in prettyprinting libraries designed for code.  It
    was designed for use in pandoc.

category:             Text
abi:                  bd6f0412c520bc5eff29a632141c7d42
exposed:              True
exposed-modules:      Text.DocLayout
hidden-modules:
    Text.DocLayout.HasChars Text.DocLayout.ANSIFont
    Text.DocLayout.Attributed

import-dirs:          /usr/lib/ghc-9.6.6/site-local/doclayout-0.5.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/doclayout-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/doclayout-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doclayout
hs-libraries:         HSdoclayout-0.5.0.1-CujJ1EOYpiiKuHA7x2QcoQ
depends:
    base-4.18.2.1 containers-0.6.7 emojis-0.1.5-BbLPu733TaPFnd8yi2bC1O
    mtl-2.3.1 safe-0.3.21-DjuyYkeoSg19eA55FDakyc text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-doclayout/html/doclayout.haddock
haddock-html:         /usr/share/doc/haskell-doclayout/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

